/*
** Module   : MenuInterface.java
** Abstract : Define all MENU-specific attributes and methods available via a handle instance.
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 VIG 20150130 Created initial version.
*/
package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Define all MENU-specific widget attributes and methods which can be accessed via a handle
 * instance.  Attributes and methods shared by multiple widget types will be defined elsewhere.
 */
public interface MenuInterface
{
   /**
    * Get handle of an owner widget.
    * 
    * @return  See above.
    */
   @LegacyAttribute(name = "OWNER")
   public handle getOwnerHandle();
   
   /**  
    * POPUP-ONLY attribute (Graphical interfaces only).
    * It means that this MENU cannot be used as MENUBAR for a Window.
    */
   @LegacyAttribute(name = "POPUP-ONLY")
   public boolean isPopupOnly();
   
   /**
    * Set POPUP-ONLY option.
    * 
    * @param   popupOnly
    *          <code>true</code> if this menu is popup-only, <code>false</code> otherwise.
    */
   @LegacyAttribute(name = "POPUP-ONLY", setter = true)
   public void setPopupOnly(boolean popupOnly);

   /**
    * Set POPUP-ONLY option.
    * 
    * @param   popupOnly
    *          <code>true</code> if this menu is popup-only, <code>false</code> otherwise.
    */
   @LegacyAttribute(name = "POPUP-ONLY", setter = true)
   public void setPopupOnly(logical popupOnly);
}
