/*
** Module   : SubMenuConfig.java
** Abstract : Sub menu widget attribute container.
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------------Description-----------------------------
** 001 VIG 20141124 Created initial version.
** 002 VIG 20150120 parentId moved to changed superclass. 
*/
package com.goldencode.p2j.ui;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;


/**
 * SUB-MENU widget configuration container.
 */
public class SubMenuConfig
extends PaneConfig
{
   /**
    * Parent widget id.
    */
   public int parentId;

   /**
    * Set new values from the provided configuration instance.
    * 
    * @param    config
    *           The instance from which to take values.
    */
   @Override
   public void applyConfig(WidgetConfig config)
   {
      super.applyConfig(config);
      
      SubMenuConfig mcfg = (SubMenuConfig) config;
      
      parentId = mcfg.parentId;
   }

   /**
    * Replacement for the default object reading method. The latest
    * state is read from the input source.  The parent's state is
    * read first.
    * 
    * @param    in
    *           The input source from which fields will be restored.
    *
    * @throws   IOException
    *           In case of I/O errors.
    * @throws   ClassNotFoundException
    *           If pay-load can't be instantiated.
    */
   @Override
   public void readExternal(ObjectInput in)
   throws IOException,
          ClassNotFoundException
   {
      super.readExternal(in);
      
      parentId = in.readInt();
   }

   /**
    * Replacement for the default object writing method. The latest
    * state is written to the output destination.  The parent's state is
    * written first.
    * 
    * @param    out
    *           The output destination to which fields will be saved.
    *
    * @throws   IOException
    *           In case of I/O errors.
    */
   @Override
   public void writeExternal(ObjectOutput out)
   throws IOException
   {
      super.writeExternal(out);
      
      out.writeInt(parentId);
   }
}
