/*
** Module   : MenuChuiImpl.java
** Abstract : CHUI client implementation of Menu.
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------------Description-----------------------------
** 001 VIG 20150116 Created initial version.
*/
package com.goldencode.p2j.ui.client.chui;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.chui.driver.ChuiOutputManager;
import com.goldencode.p2j.ui.client.widget.*;

/**
 * <code>Menu</code> CHUI client implementation class. 
 */
public class MenuChuiImpl
extends Menu<ChuiOutputManager>
{
   /**
    * Special constructor used to restore component using given configuration.
    * 
    * @param   id
    *          The widget's ID.
    * @param   cfg
    *          Configuration data.
    */
   public MenuChuiImpl(WidgetId id, WidgetConfig cfg)
   {
      super(id, (MenuConfig) cfg);
   }

   /**
    * Draw the peer container. The methods calls the draw() method for
    * ScrollPane instance for the peer container. In addition the required
    * clipping rectangle is calculated for ChildFrame containers because they
    * must be rendered inside the parent container.
    * <p>
    * Drawing for the redirected terminal differs. Labels/headers are drawn
    * only once per page, instead of the usual once per menu.
    */
   @Override
   public void draw()
   {
      // TODO super.draw(); raises the config error.
      
      //ThinClient tc = ThinClient.getInstance();
      //Point p = location();
      
      MenuConfig config = this.config();
      Point p;
      if (!config.popupOnly)
      {
         p = new Point(0, 0);
      }
      else
      {
         Widget<ChuiOutputManager> owner = screen().getRegistry().getComponent(config.ownerId);
         WidgetConfig ownerCfg = owner.config();
         if (ownerCfg instanceof BaseConfig)
         {
            BaseConfig cfg = (BaseConfig) ownerCfg; 
            
            // TODO cfg doesn't have the values in coordinates props. Why?
            //p = new Point(cfg.row, cfg.column + cfg.heightChars);
            //p = new Point(cfg.x, cfg.y + cfg.heightPixels);
            
            p = new Point(0, 5);
         }
         else
         {
            throw new IllegalStateException("Wrong config");
         }
      }
      
      Color dColor = UiUtils.getDColor(this);
      
      for(Widget<ChuiOutputManager> w : widgets())
      {
         MenuItem<?> mi = (MenuItem<?>) w;
         screen().at(p).append(mi.config().title, dColor);
         p.x += mi.config().title.length() + 2;
      }
   }

   /**
    * Hide/show widget.
    * <p>
    * If the menu is being shown and not yet attached to a window, attached it to the default
    * window.
    * 
    * @param   visible
    *          New visible state.
    */
   @Override
   public void setVisible(boolean visible)
   {
      setDisplayed(visible);
      
      if (visible && parent() == null)
      {
         setParent((Container<ChuiOutputManager>) Window.getDefaultWindow());
      }

      super.setVisible(visible);
   }

   /**
    * Replace original version to take into account P2J specific behavior.
    * 
    * @see  com.goldencode.p2j.ui.client.widget.Widget#dimension()
    */
   @Override
   public Dimension dimension()
   {
      // TODO testing mode. Remove later
      return new Dimension(10, 1);
   }

   /**
    * Get widget location relative to container.
    * 
    * @return  relative widget location.
    */
   @Override
   public Point location()
   {
      return new Point(5, 5);
   }
}
